==> syncloud-insider-0.26.tar.gz: syncloud-insider-0.26/test/test_insider_cli.py <==
from ConfigParser import ConfigParser
import unittest
from subprocess import check_output, call
from os.path import dirname, join

test_dir = dirname(__file__)
root_dir = join(dirname(__file__), '..')
cmd = '{}/bin/insider --config-path={}/test-config/ --debug'.format(root_dir, root_dir)


class TestCli(unittest.TestCase):

    def setUp(self):
        clean_up()
        check_output('mkdir {}/test-config'.format(root_dir), shell=True)
        check_output('cp {}/test_insider.cfg {}/test-config/insider.cfg'.format(test_dir, root_dir), shell=True)

    def test_full_name_not_activated(self):

        self.assertEquals(1, call('{} full_name'.format(cmd), shell=True))

    def test_full_name_activated(self):

        check_output('cp {}/test_domain.json {}/test-config/domain.json'.format(test_dir, root_dir), shell=True)

        self.assertEquals(0, call('{} full_name'.format(cmd), shell=True))

    def test_cron(self):

        output = check_output('{} cron_on'.format(cmd), shell=True)
        self.assertTrue("\"enabled\"" in output)
        output = check_output('{} cron_on'.format(cmd), shell=True)
        self.assertTrue("\"already enabled\"" in output)

        output = check_output('{} cron_off'.format(cmd), shell=True)
        self.assertTrue("\"disabled\"" in output)
        output = check_output('{} cron_off'.format(cmd), shell=True)
        self.assertTrue("\"already disabled\"" in output)

    def test_set_redirect_info(self):

        call('cp {}/test_domain.json {}/test-config/domain.json'.format(test_dir, root_dir), shell=True)

        call('{} set_redirect_info domain1 http://api.domain1'.format(cmd), shell=True)
        parser = ConfigParser()
        parser.read('{}/test-config/insider.cfg'.format(root_dir))

        self.assertEquals(parser.get('redirect', 'domain'), 'domain1')
        self.assertEquals(parser.get('redirect', 'api_url'), 'http://api.domain1')

        output = check_output('{} full_name'.format(cmd), shell=True)
        self.assertTrue("\"device.domain.domain1\"" in output)

        call('{} set_redirect_info domain2 http://api.domain2'.format(cmd), shell=True)
        parser = ConfigParser()
        parser.read('{}/test-config/insider.cfg'.format(root_dir))

        self.assertEquals(parser.get('redirect', 'domain'), 'domain2')
        self.assertEquals(parser.get('redirect', 'api_url'), 'http://api.domain2')

        output = check_output('{} full_name'.format(cmd), shell=True)
        self.assertTrue("\"device.domain.domain2\"" in output)

    def test_acquire_domain(self):

        # TODO: Implement dummy web-server
        call('{} acquire_domain email pass domain'.format(cmd), shell=True)

    def test_drop_domain(self):

        # TODO: Implement dummy web-server
        call('{} drop_domain'.format(cmd), shell=True)

    def tearDown(self):
        clean_up()


def clean_up():
    check_output('rm -rf {}/test-config'.format(root_dir), shell=True)

==> syncloud-insider-0.27.tar.gz: syncloud-insider-0.27/test/test_insider_cli.py <==
from ConfigParser import ConfigParser
import unittest
from subprocess import check_output, call
from os.path import dirname, join

test_dir = dirname(__file__)
root_dir = join(dirname(__file__), '..')
cmd = '{}/bin/insider --config-path={}/test-config/ --debug'.format(root_dir, root_dir)


class TestCli(unittest.TestCase):

    def setUp(self):
        clean_up()
        check_output('mkdir {}/test-config'.format(root_dir), shell=True)
        copy_conf('insider.cfg')

    def test_full_name_not_activated(self):

        self.assertEquals(1, call('{} full_name'.format(cmd), shell=True))

    def test_full_name_activated(self):

        copy_conf('domain.json')
        self.assertEquals(0, call('{} full_name'.format(cmd), shell=True))

    def test_cron(self):

        output = check_output('{} cron_on'.format(cmd), shell=True)
        self.assertTrue("\"enabled\"" in output)
        output = check_output('{} cron_on'.format(cmd), shell=True)
        self.assertTrue("\"already enabled\"" in output)

        output = check_output('{} cron_off'.format(cmd), shell=True)
        self.assertTrue("\"disabled\"" in output)
        output = check_output('{} cron_off'.format(cmd), shell=True)
        self.assertTrue("\"already disabled\"" in output)

    def test_set_redirect_info(self):

        copy_conf('domain.json')
        call('{} set_redirect_info domain1 http://api.domain1'.format(cmd), shell=True)
        parser = ConfigParser()
        parser.read('{}/test-config/insider.cfg'.format(root_dir))

        self.assertEquals(parser.get('redirect', 'domain'), 'domain1')
        self.assertEquals(parser.get('redirect', 'api_url'), 'http://api.domain1')

        output = check_output('{} full_name'.format(cmd), shell=True)
        self.assertTrue("\"device.domain.domain1\"" in output)

        call('{} set_redirect_info domain2 http://api.domain2'.format(cmd), shell=True)
        parser = ConfigParser()
        parser.read('{}/test-config/insider.cfg'.format(root_dir))

        self.assertEquals(parser.get('redirect', 'domain'), 'domain2')
        self.assertEquals(parser.get('redirect', 'api_url'), 'http://api.domain2')

        output = check_output('{} full_name'.format(cmd), shell=True)
        self.assertTrue("\"device.domain.domain2\"" in output)

    def test_acquire_domain(self):

        # TODO: Implement dummy web-server
        call('{} acquire_domain email pass domain'.format(cmd), shell=True)

    def test_drop_domain(self):

        call('{} drop_domain'.format(cmd), shell=True)
        self.assertEquals(1, call('{} full_name'.format(cmd), shell=True))

    def test_service_info(self):

        copy_conf('domain.json')
        copy_conf('ports.json')
        copy_conf('services.json')

        output = check_output('{} service_info ssh'.format(cmd), shell=True)
        self.assertTrue("\"type\": \"_ssh._tcp\"" in output, output)
        self.assertTrue("\"port\": \"1022\"" in output, output)
        self.assertTrue("\"external_port\": 10000" in output, output)
        self.assertTrue("\"domain\": \"device.domain.localhost\"" in output, output)

    def tearDown(self):
        clean_up()


def copy_conf(conf):
    call('cp {}/conf/{} {}/test-config'.format(test_dir, conf, root_dir), shell=True)


def clean_up():
    check_output('rm -rf {}/test-config'.format(root_dir), shell=True)
